## Final Project CS107/AC207/CS207
### Group 29
#### Members

1. Tao Tsui
2. Jenny Wang
3. Dashiell Saver-Young
4. Apisada Chulakadabba

Build Status for master branch
[![Build Status m2](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject.svg?branch=master)](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject)


Build Status for m2 branch
[![Build Status m2](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject.svg?branch=m2)](https://travis-ci.com/climate-change-is-real-python-dev/cs107-FinalProject)



CodeCov Badge for master branch
[![codecov](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject)

CodeCov Badge for m2 branch
[![codecov](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject/branch/m2/graph/badge.svg)](https://codecov.io/gh/climate-change-is-real-python-dev/cs107-FinalProject)

